@@ -1,6 +1,6 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001-2004 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2001-2005 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,10 +25,7 @@
 #include <time.h>
 #include <math.h>
 #include <ctype.h>
-#ifdef __FreeBSD__
-	#include <machine/param.h>
-	#include <sys/types.h>
-#endif
+#include <sys/types.h>
 
 #if defined(HAVE_SYS_SHM_H)
 #include <sys/ipc.h>
@@ -53,13 +50,14 @@
 #include "types.h"
 #include "log.h"
 #include "wwl.h"
+#include "gui_netkeyer.h"
 
 /* defines and variables for shared memory support */
 #define KEY 6146
 #define SHMSIZE	40
 void *shareCall;
 
-extern GtkWidget *mainwindow, *b4dialog;
+extern GtkWidget *mainwindow, *b4dialog, *keyerwindow;
 extern gint callid;
 extern statetype state;
 extern GList *logwindowlist;
@@ -400,18 +398,40 @@ on_modebutton_clicked (GtkButton * button, gpointer user_data)
 	g_strfreev (modespl);
 }
 
+/* fill in the rst field, if the keyerwindow is active and the default rst
+   contains the '#' macro, substitute it with the counter */
 void
 on_rstbutton_clicked (GtkButton * button, gpointer user_data)
 {
-	GtkWidget *entry;
+	GtkWidget *rstentry, *count;
+	gint c;
+	gchar *str, *countstr;
 
-	entry = lookup_widget (mainwindow, "rstentry");
+	rstentry = lookup_widget (mainwindow, "rstentry");
 	if (g_ascii_strcasecmp (preferences.defaulttxrst, "?"))
-		gtk_entry_set_text (GTK_ENTRY (entry), preferences.defaulttxrst);
+	{
+		if (keyerwindow && g_strrstr (preferences.defaulttxrst, "#"))
+		{
+			count = lookup_widget (keyerwindow, "count");
+			c = gtk_spin_button_get_value (GTK_SPIN_BUTTON(count));
+			if (c < 10)
+				countstr = g_strdup_printf ("00%d", c);
+			else if (c < 100)
+				countstr = g_strdup_printf ("0%d", c);
+			else
+				countstr = g_strdup_printf ("%d", c);
+			str = my_strreplace (preferences.defaulttxrst, "#", countstr);
+			g_free (countstr);
+			gtk_entry_set_text (GTK_ENTRY (rstentry), str);
+			g_free (str);
+		}
+		else
+			gtk_entry_set_text (GTK_ENTRY (rstentry), preferences.defaulttxrst);
+	}
 	else if (state.rigrst != 0)
-		gtk_entry_set_text (GTK_ENTRY (entry), state.rigrst);
+		gtk_entry_set_text (GTK_ENTRY (rstentry), state.rigrst);
 	else
-		gtk_entry_set_text (GTK_ENTRY (entry), "UNKNOWN");
+		gtk_entry_set_text (GTK_ENTRY (rstentry), "UNKNOWN");
 }
 
 void
