@@ -1,6 +1,6 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001-2004 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2001-2005 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -130,7 +130,7 @@ colwidth (gpointer arg, gint column, gint firstqso, gint printorientation,
 }
 
 void
-on_printokbutton_clicked (GtkButton * button, gpointer user_data)
+printokbutton_clicked (gpointer user_data)
 {
 	GtkWidget *printallradiobutton, *printrangeradiobutton, *printlowentry,
 		*printhighentry, *papersizecombo, *pointsizecombo, *orientationcombo,
@@ -143,7 +143,7 @@ on_printokbutton_clicked (GtkButton * button, gpointer user_data)
 		myrstok = FALSE, qsloutok = FALSE, qslinok = FALSE, powerok = FALSE, 
 		nameok = FALSE, qthok = FALSE, locatorok = FALSE, u1ok = FALSE,
 		u2ok = FALSE, remarksok = FALSE;
-	gchar *temp, *fontsize, *papersize, *psfile, **item, *pathstr;
+	gchar *temp, *fontsize, *papersize, *psfile, **item, *pathstr, *test;
 	gint i, j, k = 0, printhigh, printlow;
 	gint wnr = 100, wdate = 100, wgmt = 100, wgmtend = 100, wcall = 100, wband = 100,
 		wmode = 100, wrst = 100, wmyrst = 100, wqslout = 100,	wqslin = 100, wpower = 100,
@@ -234,8 +234,6 @@ on_printokbutton_clicked (GtkButton * button, gpointer user_data)
 		&& !qthok && !locatorok && !u1ok && !u2ok && !remarksok)
 	{
 		update_statusbar (_("No columns selected, printing cancelled..."));
-		gtk_widget_set_sensitive (mainwindow, 1);
-		gtk_widget_destroy (gtk_widget_get_toplevel (GTK_WIDGET (button)));
 		return;
 	}
 
@@ -326,6 +324,12 @@ on_printokbutton_clicked (GtkButton * button, gpointer user_data)
 	job = gnome_print_job_new (NULL);
 	config = gnome_print_job_get_config (job);
 	result = gnome_print_config_set (config, "Printer", "GENERIC");
+	test = gnome_print_config_get (config, "Printer");
+	if (!test)
+	{
+		update_statusbar (_("Cannot get printer configuration, aborting..."));
+		return;
+	}
 	result = gnome_print_config_set (config, GNOME_PRINT_KEY_PAPER_SIZE, 
 		papersize);
 	/* page size needed to calculate text position */
@@ -342,7 +346,8 @@ on_printokbutton_clicked (GtkButton * button, gpointer user_data)
 
 	/* font width and height needed to calculate text position */
 	gpc = gnome_print_job_get_context (job);
-	if (!gpc) g_error ("Error getting print context");
+	if (!gpc) g_error (_("Error while getting print environment"));
+
 	gnome_print_config_get_page_size (config, &pwidth, &pheight);
 	if (font)
 		fheight = gnome_font_get_ascender (font) + gnome_font_get_descender (font);
@@ -362,7 +367,12 @@ on_printokbutton_clicked (GtkButton * button, gpointer user_data)
 	model = gtk_tree_view_get_model (GTK_TREE_VIEW (logwindow->treeview));
 	if (gtk_tree_model_get_iter_first (model, &iter))
 	{
-		temp = g_strdup_printf (_("Printing to %s%slog.ps"), xlogdir, G_DIR_SEPARATOR_S);
+		if (preferences.printdestination == 1)
+			temp = g_strdup_printf
+				(_("Printing to %s%slog.ps"), xlogdir, G_DIR_SEPARATOR_S);
+		else
+			temp = g_strdup_printf
+				(_("Printing log in the background"));
 		update_statusbar (temp);
 
 		for (i = logwindow->qsos - printlow; i >= logwindow->qsos - printhigh; i--)
@@ -717,29 +727,9 @@ on_printokbutton_clicked (GtkButton * button, gpointer user_data)
 	g_free (fontsize);
 	g_free (psfile);
 	g_free (temp);
-
-	gtk_widget_set_sensitive (mainwindow, 1);
-	gtk_widget_destroy (gtk_widget_get_toplevel (GTK_WIDGET (button)));
 }
 
 
-/* cancel clicked, nothing printed */
-void
-on_printcancelbutton_clicked (GtkButton * button, gpointer user_data)
-{
-	gtk_widget_set_sensitive (mainwindow, 1);
-	gtk_widget_destroy (gtk_widget_get_toplevel (GTK_WIDGET (button)));
-}
-
-/* print dialog is deleted */
-gboolean
-on_printdialog_delete_event (GtkWidget * widget, GdkEvent * event,
-					 gpointer user_data)
-{
-	gtk_widget_set_sensitive (mainwindow, 1);
-	return FALSE;
-}
-
 /* set sensitivity of range widgets in print dialog */
 void
 on_printradiobutton_toggled (GtkToggleButton * togglebutton,
