@@ -1,6 +1,6 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001-2004 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2001-2005 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -71,7 +71,7 @@ const struct log_ops adif_ops = {
 static gint adif_qso_foreach
 (LOGDB *handle,  gint (*fn)(LOGDB*, qso_t*, gpointer arg), gpointer arg)
 {
-	gchar line [1024], sdate[16], *buffer;
+	gchar line [1024], sdate[16], *buffer, *p;
 	gchar **adifline, **adifitem, **adifid;
 	gint ret, items, i=0;
 	struct tm timestruct;
@@ -102,7 +102,8 @@ static gint adif_qso_foreach
 			if (items > 2) /* we have a valid adif line*/
 			{
 				for (i = 0; i < items; i++)
-				if (g_strrstr (adifline[i], ">") && g_strrstr (adifline[i], ":")) 
+				if (g_strrstr (adifline[i], ">") 
+						&& g_strrstr (adifline[i], ":")) 
 				/* valid adif item */
 				{
 					adifitem = g_strsplit (adifline[i], ">", 2);
@@ -112,7 +113,8 @@ static gint adif_qso_foreach
 					if (!strcasecmp (adifid[0], "CALL"))
 					{
 						adif_field = CALL;
-						q[adif_field] = g_strndup (adifitem[1], atoi(adifid[1]));
+						q[adif_field] =
+							g_strndup (adifitem[1], atoi(adifid[1]));
 					}
 					else if (!strcasecmp (adifid[0], "QSO_DATE"))
 					{
@@ -127,12 +129,14 @@ static gint adif_qso_foreach
 					else if (!strcasecmp (adifid[0], "TIME_ON"))
 					{
 						adif_field = GMT;
-						q[adif_field] = g_strndup (adifitem[1], atoi(adifid[1]));
+						q[adif_field] =
+							g_strndup (adifitem[1], atoi(adifid[1]));
 					}
 					else if (!strcasecmp (adifid[0], "TIME_OFF"))
 					{
 						adif_field = GMTEND;
-						q[adif_field] = g_strndup (adifitem[1], atoi(adifid[1]));
+						q[adif_field] =
+							g_strndup (adifitem[1], atoi(adifid[1]));
 					}
 					else if (!strcasecmp (adifid[0], "BAND"))
 					{
@@ -140,7 +144,8 @@ static gint adif_qso_foreach
 						if (!q[BAND]) 
 						{
 							adif_field = BAND;
-							q[adif_field] = g_strndup (adifitem[1], atoi(adifid[1]));
+							q[adif_field] =
+								g_strndup (adifitem[1], atoi(adifid[1]));
 						}
 					}
 					else if (!strcasecmp (adifid[0], "FREQ"))
@@ -152,57 +157,70 @@ static gint adif_qso_foreach
 							q[BAND] = NULL;
 						}
 						adif_field = BAND;
-						q[adif_field] = g_strndup (adifitem[1], atoi(adifid[1]));
+						if ((p = g_strrstr(adifitem[1], ",")))
+							*p = '.';
+						q[adif_field] =
+							g_strndup (adifitem[1], atoi(adifid[1]));
 					}
 					else if (!strcasecmp (adifid[0], "MODE"))
 					{
 						adif_field = MODE;
-						q[adif_field] = g_strndup (adifitem[1], atoi(adifid[1]));
+						q[adif_field] =
+							g_strndup (adifitem[1], atoi(adifid[1]));
 					}
 					else if (!strcasecmp (adifid[0], "TX_PWR"))
 					{
 						adif_field = POWER;
-						q[adif_field] = g_strndup (adifitem[1], atoi(adifid[1]));
+						q[adif_field] =
+							g_strndup (adifitem[1], atoi(adifid[1]));
 					}
 					else if (!strcasecmp (adifid[0], "RST_SENT"))
 					{
 						adif_field = RST;
-						q[adif_field] = g_strndup (adifitem[1], atoi(adifid[1]));
+						q[adif_field] =
+							g_strndup (adifitem[1], atoi(adifid[1]));
 					}
 					else if (!strcasecmp (adifid[0], "RST_RCVD"))
 					{
 						adif_field = MYRST;
-						q[adif_field] = g_strndup (adifitem[1], atoi(adifid[1]));
+						q[adif_field] =
+							g_strndup (adifitem[1], atoi(adifid[1]));
 					}
 					else if (!strcasecmp (adifid[0], "QSL_SENT"))
 					{
 						adif_field = QSLOUT;
-						q[adif_field] = g_strndup (adifitem[1], atoi(adifid[1]));
+						q[adif_field] =
+							g_strndup (adifitem[1], atoi(adifid[1]));
 					}
 					else if (!strcasecmp (adifid[0], "QSL_RCVD"))
 					{
 						adif_field = QSLIN;
-						q[adif_field] = g_strndup (adifitem[1], atoi(adifid[1]));
+						q[adif_field] =
+							g_strndup (adifitem[1], atoi(adifid[1]));
 					}
 					else if (!strcasecmp (adifid[0], "NAME"))
 					{
 						adif_field = NAME;
-						q[adif_field] = g_strndup (adifitem[1], atoi(adifid[1]));
+						q[adif_field] =
+							g_strndup (adifitem[1], atoi(adifid[1]));
 					}
 					else if (!strcasecmp (adifid[0], "QTH"))
 					{
 						adif_field = QTH;
-						q[adif_field] = g_strndup (adifitem[1], atoi(adifid[1]));
+						q[adif_field] =
+							g_strndup (adifitem[1], atoi(adifid[1]));
 					}
 					else if (!strcasecmp (adifid[0], "GRIDSQUARE"))
 					{
 						adif_field = LOCATOR;
-						q[adif_field] = g_strndup (adifitem[1], atoi(adifid[1]));
+						q[adif_field] =
+							g_strndup (adifitem[1], atoi(adifid[1]));
 					}
 					else if (!strcasecmp (adifid[0], "COMMENT"))
 					{
 						adif_field = REMARKS;
-						q[adif_field] = g_strndup (adifitem[1], atoi(adifid[1]));
+						q[adif_field] =
+							g_strndup (adifitem[1], atoi(adifid[1]));
 					}
 	
 					g_strfreev (adifid);
@@ -266,7 +284,7 @@ gint adif_create(LOGDB *handle)
 
 	/* write header */
 	fprintf(fp, "ADIF Export from " PACKAGE " Version " VERSION "\n"
-				"Copyright (C) 2001-2004 Joop Stakenborg <pg4i@amsat.org>\n"
+				"Copyright (C) 2001-2005 Joop Stakenborg <pg4i@amsat.org>\n"
 				"Internet:  http://www.qsl.net/pg4i/linux/xlog.html\n\n"
 				"Date of export: %s\n",
 				sdate);
@@ -333,6 +351,7 @@ static gchar *freq2band (gchar *freq)
 		{
 			case 1: return "160M";
 			case 3: return "80M";
+			case 5: return "60M";
 			case 7: return "40M";
 		}
 	}
