@@ -1,6 +1,6 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001-2004 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2001-2005 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -96,18 +96,75 @@ labels_qso_append (LOGDB * handle, const qso_t * q)
 {
 	FILE *fp = (FILE *) handle->priv;
 
-	if (preferences.saveaslabels == 0)
-		fprintf (fp, "%s\t%s\t%s\t%s\t%s\t%s\n",
-			q[DATE], q[GMT], q[CALL], q[BAND], q[MODE], q[RST]);
-	else if (preferences.saveaslabels == 1)
-		fprintf (fp, "%s\t%s\t%s\t%s\t%s\t%s\t%s\n",
-			q[DATE], q[GMT], q[CALL], q[BAND], q[MODE], q[RST], q[U1]);
-	else if (preferences.saveaslabels == 2)
-		fprintf (fp, "%s\t%s\t%s\t%s\t%s\t%s\t%s\n",
-			q[DATE], q[GMT], q[CALL], q[BAND], q[MODE], q[RST], q[U2]);
-	else
-		fprintf (fp, "%s\t%s\t%s\t%s\t%s\t%s\t%s\t%s\n",
-			q[DATE], q[GMT], q[CALL], q[BAND], q[MODE], q[RST], q[U1], q[U2]);
+	if (preferences.saveastsv[0] == '1')
+	{
+		if (q[DATE]) fprintf (fp, "%s\t", q[DATE]); else fprintf (fp, "\t");
+	}
+	if (preferences.saveastsv[2] == '1')
+	{
+		if (q[GMT]) fprintf (fp, "%s\t", q[GMT]); else fprintf (fp, "\t");
+	}
+	if (preferences.saveastsv[4] == '1')
+	{
+		if (q[GMTEND]) fprintf (fp, "%s\t", q[GMTEND]); else fprintf (fp, "\t");
+	}
+	if (preferences.saveastsv[6] == '1')
+	{
+		if (q[CALL]) fprintf (fp, "%s\t", q[CALL]); else fprintf (fp, "\t");
+	}
+	if (preferences.saveastsv[8] == '1')
+	{
+		if (q[BAND]) fprintf (fp, "%s\t", q[BAND]); else fprintf (fp, "\t");
+	}
+	if (preferences.saveastsv[10] == '1')
+	{
+		if (q[MODE]) fprintf (fp, "%s\t", q[MODE]); else fprintf (fp, "\t");
+	}
+	if (preferences.saveastsv[12] == '1')
+	{
+		if (q[RST]) fprintf (fp, "%s\t", q[RST]); else fprintf (fp, "\t");
+	}
+	if (preferences.saveastsv[14] == '1')
+	{
+		if (q[MYRST]) fprintf (fp, "%s\t", q[MYRST]); else fprintf (fp, "\t");
+	}
+	if (preferences.saveastsv[16] == '1')
+	{
+		if (q[QSLOUT]) fprintf (fp, "%s\t", q[QSLOUT]); else fprintf (fp, "\t");
+	}
+	if (preferences.saveastsv[18] == '1')
+	{
+		if (q[QSLIN]) fprintf (fp, "%s\t", q[QSLIN]); else fprintf (fp, "\t");
+	}
+	if (preferences.saveastsv[20] == '1')
+	{
+		if (q[POWER]) fprintf (fp, "%s\t", q[POWER]); else fprintf (fp, "\t");
+	}
+	if (preferences.saveastsv[22] == '1')
+	{
+		if (q[NAME]) fprintf (fp, "%s\t", q[NAME]); else fprintf (fp, "\t");
+	}
+	if (preferences.saveastsv[24] == '1')
+	{
+		if (q[QTH]) fprintf (fp, "%s\t", q[QTH]); else fprintf (fp, "\t");
+	}
+	if (preferences.saveastsv[26] == '1')
+	{
+		if (q[LOCATOR]) fprintf (fp, "%s\t", q[LOCATOR]); else fprintf (fp, "\t");
+	}
+	if (preferences.saveastsv[28] == '1')
+	{
+		if (q[U1]) fprintf (fp, "%s\t", q[U1]); else fprintf (fp, "\t");
+	}
+	if (preferences.saveastsv[30] == '1')
+	{
+		if (q[U2]) fprintf (fp, "%s\t", q[U2]); else fprintf (fp, "\t");
+	}
+	if (preferences.saveastsv[32] == '1')
+	{
+		if (q[REMARKS]) fprintf (fp, "%s\t", q[REMARKS]); else fprintf (fp, "\t");
+	}
+	fprintf (fp, "\n");
 	return 0;
 }
 
