@@ -1,6 +1,6 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001 - 2004 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2001 - 2005 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -76,10 +76,6 @@ extern preferencestype preferences;
 extern remotetype remote;
 extern GtkWidget *b4dialog;
 
-#if WANT_HAMLIB
-GList *riglist = NULL;
-#endif
-
 /* command line options */
 static void
 parsecommandline (int argc, char *argv[])
@@ -94,7 +90,8 @@ parsecommandline (int argc, char *argv[])
 			case ':':
 			case '?':
 			case 'h':
-				g_print ("Usage: %s [option] <log1.xlog> <log2.xlog>... \n", PACKAGE);
+				g_print ("Usage: %s [option] <log1.xlog> <log2.xlog>... \n",
+					PACKAGE);
 				g_print ("	-h	Display this help and exit\n");
 				g_print ("	-v	Output version information and exit\n");
 				exit (0);
@@ -172,6 +169,14 @@ setdefaultstate (void)
 	state.notdupecheckband = FALSE;
 }
 
+static gboolean 
+check_gtk_version (void)
+{
+	if ((gtk_major_version >= 2) && (gtk_minor_version >= 4))
+		return FALSE;
+	return TRUE;
+}
+
 /* the fun starts here */
 gint
 main (int argc, char *argv[])
@@ -179,13 +184,13 @@ main (int argc, char *argv[])
 	GtkWidget *bandoptionmenu, *modeoptionmenu, *dateentry, *qsoframe,
 		*dxccframe, *bandentry, *modeentry, *clocklabel,
 		*clockhandlebox, *mhzlabel, *mhzbutton,
-		*frequencylabel, *frequencyhandlebox, *modelabel, *modebutton, *rstlabel,
-		*rstbutton, *smeterhandlebox, *smeterdrawingarea,
+		*frequencylabel, *frequencyhandlebox, *modelabel, *modebutton,
+		*rstlabel, *rstbutton, *smeterhandlebox, *smeterdrawingarea,
 		*hpaned, *powerlabel, *powerbutton, *locatorframe, *unknownlabel1,
 		*unknownlabel2, *handlebox;
 	gchar *xlogfile, *xlogbackupfile, *temp, *logstoload, **loglist = NULL;
-	gint i, ctyresult;
-	gboolean showmainwindow = TRUE, logsfromprefs = FALSE;
+	gint i, j, ctyresult;
+	gboolean showmainwindow = TRUE, logsfromprefs = FALSE, gtk_mismatch = FALSE;
 	logtype *logwindow = NULL;
 	LOGDB *lp = NULL;
 
@@ -203,9 +208,17 @@ main (int argc, char *argv[])
 
 	gtk_set_locale ();
 	gtk_init (&argc, &argv);
+	gtk_mismatch = check_gtk_version ();
+	if (gtk_mismatch)
+	{
+		warningdialog (_("xlog - startup"),
+			_("xlog needs at least version 2.4 of the GTK+ libraries"), "gtk-dialog-error");
+		exit (1);
+	}
 	setlocale(LC_NUMERIC, "C");
 
-	add_pixmap_directory (DATADIR G_DIR_SEPARATOR_S "pixmaps" G_DIR_SEPARATOR_S "xlog");
+	add_pixmap_directory
+		(DATADIR G_DIR_SEPARATOR_S "pixmaps" G_DIR_SEPARATOR_S "xlog");
 
 	showmainwindow = xlogdircheck();
 	loadpreferences ();
@@ -222,7 +235,7 @@ main (int argc, char *argv[])
 
 	ctyresult = readctydata ();
 	if (ctyresult)
-		g_warning ("could not read cty.dat");
+		g_warning (_("Could not read cty.dat"));
 	ctyresult = readxlogdata ();
 
 	qso = g_new0 (gchar *, QSO_FIELDS);
@@ -243,7 +256,8 @@ main (int argc, char *argv[])
 	mainnotebook = gtk_notebook_new ();
 	gtk_widget_show (mainnotebook);
 	hpaned = lookup_widget (mainwindow, "hpaned");
-	gtk_paned_pack2 (GTK_PANED (hpaned), mainnotebook, TRUE, FALSE);
+	gtk_paned_pack2 (GTK_PANED (hpaned), mainnotebook, TRUE, TRUE);
+	gtk_paned_set_position (GTK_PANED (hpaned), preferences.handlebarpos);
 
 	if (!g_dir_open (preferences.savedir, 0, NULL))
 		preferences.savedir = g_strdup (xlogdir);
@@ -268,6 +282,7 @@ main (int argc, char *argv[])
 		loglist = g_strsplit (logs->str, "\n", -1);
 
 	state.utf8error = FALSE;
+	j = 0;
 	for (i = 0;; i++)
 	{
 		if (!loglist || !loglist[i] || (strlen(loglist[i]) == 0))
@@ -286,19 +301,26 @@ main (int argc, char *argv[])
 		lp = log_file_open (xlogfile, TYPE_FLOG);
 		if (lp)
 		{
-			logwindow = openlog (lp, loglist[i], i);
+			logwindow = openlog (lp, loglist[i], j);
 			log_file_qso_foreach (lp, fillin_list, logwindow);
 			log_file_close (lp);
 			logwindow->filename = g_strdup (xlogfile);
 			logwindowlist = g_list_append (logwindowlist, logwindow);
 			/* backup */
-			xlogbackupfile = g_strconcat (xlogfile, ".backup", NULL);
+			if (preferences.backup == 1)
+				xlogbackupfile = g_strconcat (xlogfile, ".backup", NULL);
+		
+			else
+				xlogbackupfile = g_strconcat
+					(preferences.backupdir, G_DIR_SEPARATOR_S, 
+					g_path_get_basename(xlogfile), ".backup", NULL);
 			backuplog (xlogfile, xlogbackupfile);
 			g_free (xlogbackupfile);
+			j++;
 		}
 		g_free (xlogfile);
 	}
-	state.logwindows = i;
+	state.logwindows = j;
 	g_strfreev (loglist);
 	g_string_free (logs, TRUE);
 	set_tabs_menu ();
@@ -311,7 +333,8 @@ main (int argc, char *argv[])
 		logwindow = g_list_nth_data (logwindowlist, 0);
 	set_qsoframe (logwindow);
 
-	/* we have to set the labels of the unknown fields, wether they are visible or not */
+	/* we have to set the labels of the unknown fields, 
+		wether they are visible or not */
 	unknownlabel1 = lookup_widget (mainwindow, "unknownlabel1");
 	gtk_label_set_text (GTK_LABEL (unknownlabel1), preferences.freefield1);
 	unknownlabel2 = lookup_widget (mainwindow, "unknownlabel2");
@@ -407,25 +430,17 @@ main (int argc, char *argv[])
 	g_signal_connect (G_OBJECT (powerbutton), "clicked",
 					G_CALLBACK (on_powerbutton_clicked), NULL);
 
-	/* need this to set popdown strings in prefs dialog */
-	rig_set_debug (RIG_DEBUG_NONE);
-	riglist = riglist_get_list ();
-
 	/* init rig if hamlib is enabled and show/hide some widgets */
 	if (preferences.hamlib > 0)
 		hamlibresult = start_hamlib (preferences.radio, preferences.device, 
 			RIG_DEBUG_NONE, preferences.polltime);
 
-
 	g_signal_connect (G_OBJECT (smeterdrawingarea), "configure_event",
-											G_CALLBACK (on_smeterdrawingarea_configure_event),
-											NULL);
+		G_CALLBACK (on_smeterdrawingarea_configure_event), NULL);
 	g_signal_connect (G_OBJECT (smeterdrawingarea), "expose_event",
-											G_CALLBACK (on_smeterdrawingarea_expose_event),
-											NULL);
+		G_CALLBACK (on_smeterdrawingarea_expose_event),	NULL);
 	g_signal_connect (G_OBJECT (mainwindow), "show",
-											G_CALLBACK (on_mainwindow_show), NULL);
- 
+		G_CALLBACK (on_mainwindow_show), NULL); 
 	sethamlibwidgets (preferences.hamlib, FALSE);
 
 #else /* hide some hamlib widgets, 
@@ -477,7 +492,14 @@ trace hamlib menu is disabled in gui_mainwindow.c */
 			_("There were some errors converting from your locale to UTF8, "
 			"which is used by GTK+ internally. It is best if you start xlog "
 			"from a terminal and see what the errors are. Please check your "
-			"language settings and your log fields!"));
+			"language settings and your log fields!"), "gtk-dialog-warning");
+	}
+	if (j < i)
+	{
+		warningdialog (_("xlog - error"), 
+			_("There was an error while loading one of your logs, "
+			"you may want to start xlog from a terminal "
+			"to see what the errors are."), "gtk-dialog-error");
 	}
 
 	gtk_main ();
