@@ -1,6 +1,6 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001-2004 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2001-2005 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -33,13 +33,11 @@
 
 preferencestype preferences;
 extern gchar *xlogdir;
-#define PREFERENCES_VERSION 2
+#define PREFERENCES_VERSION 4
 gboolean newprefsfile = FALSE;
 
 static void make_default_preferences (void)
 {
-	GString *sdir = g_string_new ("");
-
 	preferences.version = 0;
 	preferences.x = 10;
 	preferences.y = 30;
@@ -72,11 +70,12 @@ static void make_default_preferences (void)
 	preferences.themefont = g_strdup ("Sans 10");
 	preferences.logcolor = 1;
 	preferences.autosave = 5;
-	g_string_printf (sdir, "%s.", G_DIR_SEPARATOR_S);
-	g_string_append (sdir, PACKAGE);
-	preferences.savedir = g_strconcat (g_get_home_dir (), sdir->str, NULL);
-	g_string_free (sdir, TRUE);
+	preferences.savedir = g_strdup_printf ("%s%s.%s",
+		g_get_home_dir (), G_DIR_SEPARATOR_S, PACKAGE);
+	preferences.backupdir = g_strdup_printf ("%s%s.%s",
+		g_get_home_dir (), G_DIR_SEPARATOR_S, PACKAGE);
 	preferences.saving = 1;
+	preferences.backup = 1;
 	preferences.logstoload = g_strdup ("*");
 	preferences.locator = g_strdup ("AA00AA");
 	preferences.freefield1 = g_strdup ("UNKNOWN");
@@ -101,7 +100,24 @@ static void make_default_preferences (void)
 	preferences.b4width = 500;
 	preferences.b4height = 300;
 	preferences.saveasadif = 0;
-	preferences.saveaslabels = 0;
+	preferences.saveastsv = g_strdup ("1,1,0,1,1,1,1,0,0,0,0,0,0,0,0,0,0");
+	preferences.handlebarpos = 300;
+	preferences.cwf1 = g_strdup ("cq de % % test");
+	preferences.cwf2 = g_strdup ("@ de %");
+	preferences.cwf3 = g_strdup ("@ ++5nn--#");
+	preferences.cwf4 = g_strdup ("tu 73");
+	preferences.cwf5 = g_strdup ("@");
+	preferences.cwf6 = g_strdup ("%");
+	preferences.cwf7 = g_strdup ("@ sri qso b4 gl");
+	preferences.cwf8 = g_strdup ("agn");
+	preferences.cwf9 = g_strdup ("?");
+	preferences.cwf10 = g_strdup ("qrz?");
+	preferences.cwf11 = g_strdup ("pse k");
+	preferences.cwf12 = g_strdup ("++++test---- % %");
+	preferences.cwcq = g_strdup ("tu %");
+	preferences.cwsp = g_strdup ("tu 5nn#");
+	preferences.cwspeed = 24;
+	preferences.fcc = 0;
 }
 
 void
@@ -115,591 +131,469 @@ parseloadpreferences (xmlDocPtr p, xmlNodePtr cur)
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.version = atoi (key);
-#ifdef WIN32
 			free (key);
-#else
-			xmlFree (key);
-#endif
 		}
 		if ((!xmlStrcmp(cur->name, (const xmlChar *)"x")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.x = atoi (key);
-#ifdef WIN32
 			free (key);
-#else
-			xmlFree (key);
-#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"y")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.y = atoi (key);
-#ifdef WIN32
 			free (key);
-#else
-			xmlFree (key);
-#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"width")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.width = atoi (key);
-#ifdef WIN32
 			free (key);
-#else
-			xmlFree (key);
-#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"height")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.height = atoi (key);
-#ifdef WIN32
 			free (key);
-#else
-			xmlFree (key);
-#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"latitude")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.latitude = atof (key);
-#ifdef WIN32
 			free (key);
-#else
-			xmlFree (key);
-#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"NS")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.NS = atoi (key);
-#ifdef WIN32
 			free (key);
-#else
-			xmlFree (key);
-#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"longitude")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.longitude = atof (key);
-#ifdef WIN32
 			free (key);
-#else
-			xmlFree (key);
-#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"EW")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.EW = atoi (key);
-#ifdef WIN32
 			free (key);
-#else
-			xmlFree (key);
-#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"units")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.units = atoi (key);
-#ifdef WIN32
 			free (key);
-#else
-			xmlFree (key);
-#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"bands")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.bands = g_strdup (key);
-#ifdef WIN32
 			free (key);
-#else
-			xmlFree (key);
-#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"modes")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.modes = g_strdup (key);
-#ifdef WIN32
 			free (key);
-#else
-			xmlFree (key);
-#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"modeseditbox")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.modeseditbox = atoi (key);
-#ifdef WIN32
 			free (key);
-#else
-			xmlFree (key);
-#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"bandseditbox")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.bandseditbox = atoi (key);
-#ifdef WIN32
 			free (key);
-#else
-			xmlFree (key);
-#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"bandoptionmenu")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.bandoptionmenu = atoi (key);
-#ifdef WIN32
 			free (key);
-#else
-			xmlFree (key);
-#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"modeoptionmenu")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.modeoptionmenu = atoi (key);
-#ifdef WIN32
 			free (key);
-#else
-			xmlFree (key);
-#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"printall")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.printall = atoi (key);
-#ifdef WIN32
 			free (key);
-#else
-			xmlFree (key);
-#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"printsize")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.printsize = atoi (key);
-#ifdef WIN32
 			free (key);
-#else
-			xmlFree (key);
-#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"printpoint")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.printpoint = atoi (key);
-#ifdef WIN32
 			free (key);
-#else
-			xmlFree (key);
-#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"printdestination")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.printdestination = atoi (key);
-#ifdef WIN32
 			free (key);
-#else
-			xmlFree (key);
-#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"printorientation")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.printorientation = atoi (key);
-#ifdef WIN32
 			free (key);
-#else
-			xmlFree (key);
-#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"hamlib")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.hamlib = atoi (key);
-#ifdef WIN32
 			free (key);
-#else
-			xmlFree (key);
-#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"radio")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.radio = g_strdup (key);
-#ifdef WIN32
 			free (key);
-#else
-			xmlFree (key);
-#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"device")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.device = g_strdup (key);
-#ifdef WIN32
 			free (key);
-#else
-			xmlFree (key);
-#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"rigconf")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.rigconf = g_strdup (key);
-#ifdef WIN32
 			free (key);
-#else
-			xmlFree (key);
-#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"round")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.round = atoi (key);
-#ifdef WIN32
 			free (key);
-#else
-			xmlFree (key);
-#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"polltime")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.polltime = atoi (key);
-#ifdef WIN32
 			free (key);
-#else
-			xmlFree (key);
-#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"clock")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.clock = atoi (key);
-#ifdef WIN32
 			free (key);
-#else
-			xmlFree (key);
-#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"themecolor")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.themecolor = g_strdup (key);
-#ifdef WIN32
 			free (key);
-#else
-			xmlFree (key);
-#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"themefont")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.themefont = g_strdup (key);
-#ifdef WIN32
 			free (key);
-#else
-			xmlFree (key);
-#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"logcolor")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.logcolor = atoi (key);
-#ifdef WIN32
 			free (key);
-#else
-			xmlFree (key);
-#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"autosave")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.autosave = atoi (key);
-#ifdef WIN32
 			free (key);
-#else
-			xmlFree (key);
-#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"savedir")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.savedir = g_strdup (key);
-#ifdef WIN32
 			free (key);
-#else
-			xmlFree (key);
-#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"saving")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.saving = atoi (key);
-#ifdef WIN32
 			free (key);
-#else
-			xmlFree (key);
-#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"logstoload")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.logstoload = g_strdup (key);
-#ifdef WIN32
 			free (key);
-#else
-			xmlFree (key);
-#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"locator")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.locator = g_strdup (key);
-#ifdef WIN32
 			free (key);
-#else
-			xmlFree (key);
-#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"freefield1")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.freefield1 = g_strdup (key);
-#ifdef WIN32
 			free (key);
-#else
-			xmlFree (key);
-#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"freefield2")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.freefield2 = g_strdup (key);
-#ifdef WIN32
 			free (key);
-#else
-			xmlFree (key);
-#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"callsign")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.callsign = g_strdup (key);
-#ifdef WIN32
 			free (key);
-#else
-			xmlFree (key);
-#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"defaultmhz")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.defaultmhz = g_strdup (key);
-#ifdef WIN32
 			free (key);
-#else
-			xmlFree (key);
-#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"defaultmode")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.defaultmode = g_strdup (key);
-#ifdef WIN32
 			free (key);
-#else
-			xmlFree (key);
-#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"defaulttxrst")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.defaulttxrst = g_strdup (key);
-#ifdef WIN32
 			free (key);
-#else
-			xmlFree (key);
-#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"defaultrxrst")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.defaultrxrst = g_strdup (key);
-#ifdef WIN32
 			free (key);
-#else
-			xmlFree (key);
-#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"defaultpower")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.defaultpower = g_strdup (key);
-#ifdef WIN32
 			free (key);
-#else
-			xmlFree (key);
-#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"defaultfreefield1")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.defaultfreefield1 = g_strdup (key);
-#ifdef WIN32
 			free (key);
-#else
-			xmlFree (key);
-#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"defaultfreefield2")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.defaultfreefield2 = g_strdup (key);
-#ifdef WIN32
 			free (key);
-#else
-			xmlFree (key);
-#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"defaultremarks")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.defaultremarks = g_strdup (key);
-#ifdef WIN32
 			free (key);
-#else
-			xmlFree (key);
-#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"b4columns")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.b4columns = g_strdup (key);
-#ifdef WIN32
 			free (key);
-#else
-			xmlFree (key);
-#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"logcwidths")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.logcwidths = g_strdup (key);
-#ifdef WIN32
 			free (key);
-#else
-			xmlFree (key);
-#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"typeaheadfind")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.typeaheadfind = atoi (key);
-#ifdef WIN32
 			free (key);
-#else
-			xmlFree (key);
-#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"remoteadding")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.remoteadding = atoi (key);
-#ifdef WIN32
 			free (key);
-#else
-			xmlFree (key);
-#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"viewtoolbar")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.viewtoolbar = atoi (key);
-#ifdef WIN32
 			free (key);
-#else
-			xmlFree (key);
-#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"viewb4")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.viewb4 = atoi (key);
-#ifdef WIN32
 			free (key);
-#else
-			xmlFree (key);
-#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"b4x")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.b4x = atoi (key);
-#ifdef WIN32
 			free (key);
-#else
-			xmlFree (key);
-#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"b4y")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.b4y = atoi (key);
-#ifdef WIN32
 			free (key);
-#else
-			xmlFree (key);
-#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"b4width")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.b4width = atoi (key);
-#ifdef WIN32
 			free (key);
-#else
-			xmlFree (key);
-#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"b4height")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.b4height = atoi (key);
-#ifdef WIN32
 			free (key);
-#else
-			xmlFree (key);
-#endif
 		}
 		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"saveasadif")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
 			preferences.saveasadif = atoi (key);
-#ifdef WIN32
 			free (key);
-#else
-			xmlFree (key);
-#endif
 		}
-		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"saveaslabels")))
+		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"saveastsv")))
 		{
 			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
-			preferences.saveaslabels = atoi (key);
-#ifdef WIN32
+			preferences.saveastsv = g_strdup (key);
+			free (key);
+		}
+		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"handlebarpos")))
+		{
+			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
+			preferences.handlebarpos = atoi (key);
+			free (key);
+		}
+		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"cwf1")))
+		{
+			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
+			preferences.cwf1 = g_strdup (key);
+			free (key);
+		}
+		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"cwf2")))
+		{
+			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
+			preferences.cwf2 = g_strdup (key);
+			free (key);
+		}
+		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"cwf3")))
+		{
+			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
+			preferences.cwf3 = g_strdup (key);
+			free (key);
+		}
+		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"cwf4")))
+		{
+			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
+			preferences.cwf4 = g_strdup (key);
+			free (key);
+		}
+		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"cwf5")))
+		{
+			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
+			preferences.cwf5 = g_strdup (key);
+			free (key);
+		}
+		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"cwf6")))
+		{
+			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
+			preferences.cwf6 = g_strdup (key);
+			free (key);
+		}
+		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"cwf7")))
+		{
+			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
+			preferences.cwf7 = g_strdup (key);
+			free (key);
+		}
+		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"cwf8")))
+		{
+			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
+			preferences.cwf8 = g_strdup (key);
+			free (key);
+		}
+		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"cwf9")))
+		{
+			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
+			preferences.cwf9 = g_strdup (key);
+			free (key);
+		}
+		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"cwf10")))
+		{
+			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
+			preferences.cwf10 = g_strdup (key);
+			free (key);
+		}
+		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"cwf11")))
+		{
+			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
+			preferences.cwf11 = g_strdup (key);
+			free (key);
+		}
+		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"cwf12")))
+		{
+			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
+			preferences.cwf12 = g_strdup (key);
+			free (key);
+		}
+		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"cwcq")))
+		{
+			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
+			preferences.cwcq = g_strdup (key);
+			free (key);
+		}
+		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"cwsp")))
+		{
+			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
+			preferences.cwsp = g_strdup (key);
+			free (key);
+		}
+		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"cwspeed")))
+		{
+			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
+			preferences.cwspeed = atoi (key);
+			free (key);
+		}
+		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"backupdir")))
+		{
+			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
+			preferences.backupdir = g_strdup (key);
+			free (key);
+		}
+		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"backup")))
+		{
+			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
+			preferences.backup = atoi (key);
+			free (key);
+		}
+		else if ((!xmlStrcmp(cur->name, (const xmlChar *)"fcc")))
+		{
+			key = xmlNodeListGetString (p, cur->xmlChildrenNode, 1);
+			preferences.fcc = atoi (key);
 			free (key);
-#else
-			xmlFree (key);
-#endif
 		}
 	cur = cur->next;
 	}
@@ -1061,9 +955,123 @@ void parsesavepreferences (xmlNodePtr cur)
 			xmlNodeSetContent (node, key);
 			g_free (key);
 		}
-		else if (!strcmp (node->name, "saveaslabels"))
+		else if (!strcmp (node->name, "saveastsv"))
 		{
-			key = g_strdup_printf ("%d", preferences.saveaslabels);
+			key = g_strdup_printf ("%s", preferences.saveastsv);
+			xmlNodeSetContent (node, key);
+			g_free (key);
+		}
+		else if (!strcmp (node->name, "handlebarpos"))
+		{
+			key = g_strdup_printf ("%d", preferences.handlebarpos);
+			xmlNodeSetContent (node, key);
+			g_free (key);
+		}
+		else if (!strcmp (node->name, "cwf1"))
+		{
+			key = g_strdup_printf ("%s", preferences.cwf1);
+			xmlNodeSetContent (node, key);
+			g_free (key);
+		}
+		else if (!strcmp (node->name, "cwf2"))
+		{
+			key = g_strdup_printf ("%s", preferences.cwf2);
+			xmlNodeSetContent (node, key);
+			g_free (key);
+		}
+		else if (!strcmp (node->name, "cwf3"))
+		{
+			key = g_strdup_printf ("%s", preferences.cwf3);
+			xmlNodeSetContent (node, key);
+			g_free (key);
+		}
+		else if (!strcmp (node->name, "cwf4"))
+		{
+			key = g_strdup_printf ("%s", preferences.cwf4);
+			xmlNodeSetContent (node, key);
+			g_free (key);
+		}
+		else if (!strcmp (node->name, "cwf5"))
+		{
+			key = g_strdup_printf ("%s", preferences.cwf5);
+			xmlNodeSetContent (node, key);
+			g_free (key);
+		}
+		else if (!strcmp (node->name, "cwf6"))
+		{
+			key = g_strdup_printf ("%s", preferences.cwf6);
+			xmlNodeSetContent (node, key);
+			g_free (key);
+		}
+		else if (!strcmp (node->name, "cwf7"))
+		{
+			key = g_strdup_printf ("%s", preferences.cwf7);
+			xmlNodeSetContent (node, key);
+			g_free (key);
+		}
+		else if (!strcmp (node->name, "cwf8"))
+		{
+			key = g_strdup_printf ("%s", preferences.cwf8);
+			xmlNodeSetContent (node, key);
+			g_free (key);
+		}
+		else if (!strcmp (node->name, "cwf9"))
+		{
+			key = g_strdup_printf ("%s", preferences.cwf9);
+			xmlNodeSetContent (node, key);
+			g_free (key);
+		}
+		else if (!strcmp (node->name, "cwf10"))
+		{
+			key = g_strdup_printf ("%s", preferences.cwf10);
+			xmlNodeSetContent (node, key);
+			g_free (key);
+		}
+		else if (!strcmp (node->name, "cwf11"))
+		{
+			key = g_strdup_printf ("%s", preferences.cwf11);
+			xmlNodeSetContent (node, key);
+			g_free (key);
+		}
+		else if (!strcmp (node->name, "cwf12"))
+		{
+			key = g_strdup_printf ("%s", preferences.cwf12);
+			xmlNodeSetContent (node, key);
+			g_free (key);
+		}
+		else if (!strcmp (node->name, "cwcq"))
+		{
+			key = g_strdup_printf ("%s", preferences.cwcq);
+			xmlNodeSetContent (node, key);
+			g_free (key);
+		}
+		else if (!strcmp (node->name, "cwsp"))
+		{
+			key = g_strdup_printf ("%s", preferences.cwsp);
+			xmlNodeSetContent (node, key);
+			g_free (key);
+		}
+		else if (!strcmp (node->name, "cwspeed"))
+		{
+			key = g_strdup_printf ("%d", preferences.cwspeed);
+			xmlNodeSetContent (node, key);
+			g_free (key);
+		}
+		else if (!strcmp (node->name, "backupdir"))
+		{
+			key = g_strdup (preferences.backupdir);
+			xmlNodeSetContent (node, key);
+			g_free (key);
+		}
+		else if (!strcmp (node->name, "backup"))
+		{
+			key = g_strdup_printf ("%d", preferences.backup);
+			xmlNodeSetContent (node, key);
+			g_free (key);
+		}
+		else if (!strcmp (node->name, "fcc"))
+		{
+			key = g_strdup_printf ("%d", preferences.fcc);
 			xmlNodeSetContent (node, key);
 			g_free (key);
 		}
@@ -1193,8 +1201,46 @@ newsavepreferences (xmlNodePtr cur)
 	xmlNewTextChild (cur, NULL, "b4height", key);
 	key = g_strdup_printf ("%d", preferences.saveasadif);
 	xmlNewTextChild (cur, NULL, "saveasadif", key);
-	key = g_strdup_printf ("%d", preferences.saveaslabels);
-	xmlNewTextChild (cur, NULL, "saveaslabels", key);
+	key = g_strdup_printf ("%s", preferences.saveastsv);
+	xmlNewTextChild (cur, NULL, "saveastsv", key);
+	key = g_strdup_printf ("%d", preferences.handlebarpos);
+	xmlNewTextChild (cur, NULL, "handlebarpos", key);
+	key = g_strdup_printf ("%s", preferences.cwf1);
+	xmlNewTextChild (cur, NULL, "cwf1", key);
+	key = g_strdup_printf ("%s", preferences.cwf2);
+	xmlNewTextChild (cur, NULL, "cwf2", key);
+	key = g_strdup_printf ("%s", preferences.cwf3);
+	xmlNewTextChild (cur, NULL, "cwf3", key);
+	key = g_strdup_printf ("%s", preferences.cwf4);
+	xmlNewTextChild (cur, NULL, "cwf4", key);
+	key = g_strdup_printf ("%s", preferences.cwf5);
+	xmlNewTextChild (cur, NULL, "cwf5", key);
+	key = g_strdup_printf ("%s", preferences.cwf6);
+	xmlNewTextChild (cur, NULL, "cwf6", key);
+	key = g_strdup_printf ("%s", preferences.cwf7);
+	xmlNewTextChild (cur, NULL, "cwf7", key);
+	key = g_strdup_printf ("%s", preferences.cwf8);
+	xmlNewTextChild (cur, NULL, "cwf8", key);
+	key = g_strdup_printf ("%s", preferences.cwf9);
+	xmlNewTextChild (cur, NULL, "cwf9", key);
+	key = g_strdup_printf ("%s", preferences.cwf10);
+	xmlNewTextChild (cur, NULL, "cwf10", key);
+	key = g_strdup_printf ("%s", preferences.cwf11);
+	xmlNewTextChild (cur, NULL, "cwf11", key);
+	key = g_strdup_printf ("%s", preferences.cwf12);
+	xmlNewTextChild (cur, NULL, "cwf12", key);
+	key = g_strdup_printf ("%s", preferences.cwcq);
+	xmlNewTextChild (cur, NULL, "cwcq", key);
+	key = g_strdup_printf ("%s", preferences.cwsp);
+	xmlNewTextChild (cur, NULL, "cwsp", key);
+	key = g_strdup_printf ("%d", preferences.cwspeed);
+	xmlNewTextChild (cur, NULL, "cwspeed", key);
+	key = g_strdup_printf ("%s", preferences.backupdir);
+	xmlNewTextChild (cur, NULL, "backupdir", key);
+	key = g_strdup_printf ("%d", preferences.backup);
+	xmlNewTextChild (cur, NULL, "backup", key);
+	key = g_strdup_printf ("%d", preferences.fcc);
+	xmlNewTextChild (cur, NULL, "fcc", key);
 	g_free (key);
 }
 
@@ -1303,8 +1349,56 @@ savepreferences (void)
 		        /* introduced in xlog version 0.9.10 */
 				key = g_strdup_printf ("%d", preferences.saveasadif);
 				xmlNewTextChild (cur, NULL, "saveasadif", key);
-				key = g_strdup_printf ("%d", preferences.saveaslabels);
-				xmlNewTextChild (cur, NULL, "saveaslabels", key);
+				g_free (key);
+			}
+			if (!newprefsfile && (preferences.version < 3))
+			{	
+		        /* introduced in xlog version 1.1 */
+				key = g_strdup_printf ("%s", preferences.saveastsv);
+				xmlNewTextChild (cur, NULL, "saveastsv", key);
+				key = g_strdup_printf ("%d", preferences.handlebarpos);
+				xmlNewTextChild (cur, NULL, "handlebarpos", key);
+				g_free (key);
+			}
+			if (!newprefsfile && (preferences.version < 4))
+			{	
+		        /* introduced in xlog version 1.2 */
+				key = g_strdup_printf ("%s", preferences.cwf1);
+				xmlNewTextChild (cur, NULL, "cwf1", key);
+				key = g_strdup_printf ("%s", preferences.cwf2);
+				xmlNewTextChild (cur, NULL, "cwf2", key);
+				key = g_strdup_printf ("%s", preferences.cwf3);
+				xmlNewTextChild (cur, NULL, "cwf3", key);
+				key = g_strdup_printf ("%s", preferences.cwf4);
+				xmlNewTextChild (cur, NULL, "cwf4", key);
+				key = g_strdup_printf ("%s", preferences.cwf5);
+				xmlNewTextChild (cur, NULL, "cwf5", key);
+				key = g_strdup_printf ("%s", preferences.cwf6);
+				xmlNewTextChild (cur, NULL, "cwf6", key);
+				key = g_strdup_printf ("%s", preferences.cwf7);
+				xmlNewTextChild (cur, NULL, "cwf7", key);
+				key = g_strdup_printf ("%s", preferences.cwf8);
+				xmlNewTextChild (cur, NULL, "cwf8", key);
+				key = g_strdup_printf ("%s", preferences.cwf9);
+				xmlNewTextChild (cur, NULL, "cwf9", key);
+				key = g_strdup_printf ("%s", preferences.cwf10);
+				xmlNewTextChild (cur, NULL, "cwf10", key);
+				key = g_strdup_printf ("%s", preferences.cwf11);
+				xmlNewTextChild (cur, NULL, "cwf11", key);
+				key = g_strdup_printf ("%s", preferences.cwf12);
+				xmlNewTextChild (cur, NULL, "cwf12", key);
+				key = g_strdup_printf ("%s", preferences.cwcq);
+				xmlNewTextChild (cur, NULL, "cwcq", key);
+				key = g_strdup_printf ("%s", preferences.cwsp);
+				xmlNewTextChild (cur, NULL, "cwsp", key);
+				key = g_strdup_printf ("%d", preferences.cwspeed);
+				xmlNewTextChild (cur, NULL, "cwspeed", key);
+				key = g_strdup_printf ("%s", preferences.backupdir);
+				xmlNewTextChild (cur, NULL, "backupdir", key);
+				key = g_strdup_printf ("%d", preferences.backup);
+				xmlNewTextChild (cur, NULL, "backup", key);
+				key = g_strdup_printf ("%d", preferences.fcc);
+				xmlNewTextChild (cur, NULL, "fcc", key);
 				g_free (key);
 			}
 		}
