@@ -1,6 +1,6 @@
 /*
  * xlog - GTK+ logging program for amateur radio operators
- * Copyright (C) 2001-2004 Joop Stakenborg <pg4i@amsat.org>
+ * Copyright (C) 2001-2005 Joop Stakenborg <pg4i@amsat.org>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -60,7 +60,9 @@ typedef struct
 	gint logcolor;		/* do we want to color the log? */
 	gint autosave;
 	gchar *savedir;
+	gchar *backupdir;
 	gint saving;		/* 1= autosave, 2=save with click on toolbar */
+	gint backup;		/* 1= standard, 2=safe */
 	gchar *logstoload;
 	gchar *locator;
 	gchar *freefield1;
@@ -85,7 +87,24 @@ typedef struct
 	gint b4width;
 	gint b4height;
 	gint saveasadif;
-	gint saveaslabels;
+	gchar *saveastsv;
+	gint handlebarpos;
+	gchar *cwf1;
+	gchar *cwf2;
+	gchar *cwf3;
+	gchar *cwf4;
+	gchar *cwf5;
+	gchar *cwf6;
+	gchar *cwf7;
+	gchar *cwf8;
+	gchar *cwf9;
+	gchar *cwf10;
+	gchar *cwf11;
+	gchar *cwf12;
+	gchar *cwcq;
+	gchar *cwsp;
+	gint cwspeed;
+	gint fcc;
 }
 preferencestype;
 
@@ -114,6 +133,14 @@ typedef struct
 }
 statetype;
 
+/* structure used for keyer state */
+typedef struct
+{
+	gboolean cqmode;
+	gboolean shortnr;
+}
+keyerstatetype;
+
 /* struct for remote data state */
 typedef struct
 {
